This is an automated email from the ASF dual-hosted git repository.

kou pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/arrow.git


The following commit(s) were added to refs/heads/master by this push:
     new 3ca48b3  ARROW-7487: [Developer] Fix typos
3ca48b3 is described below

commit 3ca48b3505e30069919ea773a4fffd0b1496cc1b
Author: Kazuaki Ishizaki <[email protected]>
AuthorDate: Thu Jan 2 07:10:05 2020 +0900

    ARROW-7487: [Developer] Fix typos
    
    This PR fix typos in files under `dev` directory
    
    Closes #6116 from kiszk/ARROW-7487 and squashes the following commits:
    
    753a68eb1 <Kazuaki Ishizaki> fix typo
    
    Authored-by: Kazuaki Ishizaki <[email protected]>
    Signed-off-by: Sutou Kouhei <[email protected]>
---
 dev/README.md                                              |  2 +-
 dev/archery/archery/cli.py                                 |  4 ++--
 dev/archery/archery/utils/cmake.py                         |  2 +-
 dev/benchmarking/README.md                                 |  2 +-
 dev/benchmarking/data_model.rst                            |  2 +-
 dev/benchmarking/ddl/2_00_views.sql                        |  2 +-
 .../examples/benchmark_with_context_example.json           |  2 +-
 dev/merge_arrow_pr.py                                      |  2 +-
 dev/release/02-source-test.rb                              |  2 +-
 dev/release/02-source.sh                                   |  2 +-
 dev/release/post-03-website.sh                             |  2 +-
 dev/tasks/conda-recipes/README.md                          |  4 ++--
 dev/tasks/crossbow.py                                      | 14 +++++++-------
 dev/tasks/linux-packages/apache-arrow/yum/arrow.spec.in    |  2 +-
 14 files changed, 22 insertions(+), 22 deletions(-)

diff --git a/dev/README.md b/dev/README.md
index 79a0bb4..a09fcba 100644
--- a/dev/README.md
+++ b/dev/README.md
@@ -157,7 +157,7 @@ docker-compose run --rm conda-python-hdfs
 Tests can be run to ensure that the current snapshot of Java and Python Arrow
 works with Spark. This will run a docker image to build Arrow C++
 and Python in a Conda environment, build and install Arrow Java to the local
-Maven repositiory, build Spark with the new Arrow artifact, and run Arrow
+Maven repository, build Spark with the new Arrow artifact, and run Arrow
 related unit tests in Spark for Java and Python. Any errors will exit with a
 non-zero value. To run, use the following command:
 
diff --git a/dev/archery/archery/cli.py b/dev/archery/archery/cli.py
index 234d3ba..e1cb5df 100644
--- a/dev/archery/archery/cli.py
+++ b/dev/archery/archery/cli.py
@@ -240,7 +240,7 @@ def lint(ctx, src, **kwargs):
 def benchmark(ctx):
     """ Arrow benchmarking.
 
-    Use the diff sub-command to benchmake revisions, and/or build directories.
+    Use the diff sub-command to benchmark revisions, and/or build directories.
     """
     pass
 
@@ -470,7 +470,7 @@ def _set_default(opt, default):
 
 @archery.command(short_help="Execute protocol and Flight integration tests")
 @click.option('--with-all', is_flag=True, default=False,
-              help=('Include all known lanauges by default '
+              help=('Include all known languages by default '
                     ' in integration tests'))
 @click.option('--random-seed', type=int, default=12345,
               help="Seed for PRNG when generating test data")
diff --git a/dev/archery/archery/utils/cmake.py 
b/dev/archery/archery/utils/cmake.py
index e4e15b2..4be3dc9 100644
--- a/dev/archery/archery/utils/cmake.py
+++ b/dev/archery/archery/utils/cmake.py
@@ -91,7 +91,7 @@ class CMakeDefinition:
         Parameters
         ----------
         build_dir : str
-                    Directory in which the CMake build will be instanciated.
+                    Directory in which the CMake build will be instantiated.
         force : bool
                 If the build folder exists, delete it before. Otherwise if it's
                 present, an error will be returned.
diff --git a/dev/benchmarking/README.md b/dev/benchmarking/README.md
index 27bad73..c5ddd62 100644
--- a/dev/benchmarking/README.md
+++ b/dev/benchmarking/README.md
@@ -71,7 +71,7 @@ SELECT ingest_machine_view(:'content'::jsonb);
 
 There is a file named "[.env][.env]" in this directory that is used by
 `docker-compose` to set up the postgres user and password for the
-local containers. Currentlty the name and password are both
+local containers. Currently the name and password are both
 `benchmark`. This will be the password for the psql client as well.
 
 The Postgres Alpine image runs any added '\*.sql' and '\*.sh' scripts placed
diff --git a/dev/benchmarking/data_model.rst b/dev/benchmarking/data_model.rst
index b2d03fd..d0f3dc7 100644
--- a/dev/benchmarking/data_model.rst
+++ b/dev/benchmarking/data_model.rst
@@ -308,7 +308,7 @@ environment_view
 ----------------
 
 The build environment used for a reported benchmark run.
-(Will be inferred from each "benchmark_run" if not expicitly added).
+(Will be inferred from each "benchmark_run" if not explicitly added).
 
 - Each entry is unique on
   ("benchmark_language", "language_implementation_version", "dependencies")
diff --git a/dev/benchmarking/ddl/2_00_views.sql 
b/dev/benchmarking/ddl/2_00_views.sql
index cd4b200..cbd295e 100644
--- a/dev/benchmarking/ddl/2_00_views.sql
+++ b/dev/benchmarking/ddl/2_00_views.sql
@@ -87,7 +87,7 @@ CREATE OR REPLACE VIEW public.environment_view AS
       ON env.dependencies_id = deps.dependencies_id;
 COMMENT ON VIEW public.environment_view IS
 E'The build environment used for a reported benchmark run.\n'
- '(Will be inferred from each "benchmark_run" if not expicitly added).\n\n'
+ '(Will be inferred from each "benchmark_run" if not explicitly added).\n\n'
  '- Each entry is unique on\n'
  '  ("benchmark_language", "language_implementation_version", 
"dependencies")\n'
  '- "benchmark_language" is unique in the "benchmark_language" table\n'
diff --git a/dev/benchmarking/examples/benchmark_with_context_example.json 
b/dev/benchmarking/examples/benchmark_with_context_example.json
index 4e395b0..f9e6e31 100644
--- a/dev/benchmarking/examples/benchmark_with_context_example.json
+++ b/dev/benchmarking/examples/benchmark_with_context_example.json
@@ -26,7 +26,7 @@
       "std_dev": 1.41,
       "n_obs": 8,
       "run_metadata": {"any": "json object is admissible"},
-      "run_notes": "This value is an arbitray-length string."
+      "run_notes": "This value is an arbitrary-length string."
     },
     {
       "benchmark_name": "Benchmark 2",
diff --git a/dev/merge_arrow_pr.py b/dev/merge_arrow_pr.py
index 56741be..7373f3a 100755
--- a/dev/merge_arrow_pr.py
+++ b/dev/merge_arrow_pr.py
@@ -22,7 +22,7 @@
 #   usage: ./merge_arrow_pr.py    (see config env vars below)
 #
 # This utility assumes you already have a local Arrow git clone and that you
-# have added remotes corresponding to both (i) the Github Apache Arrow mirror
+# have added remotes corresponding to both (i) the GitHub Apache Arrow mirror
 # and (ii) the apache git repo.
 #
 # There are several pieces of authorization possibly needed via environment
diff --git a/dev/release/02-source-test.rb b/dev/release/02-source-test.rb
index ac911cd..e5fb846 100644
--- a/dev/release/02-source-test.rb
+++ b/dev/release/02-source-test.rb
@@ -118,7 +118,7 @@ Subject: [VOTE] Release Apache Arrow #{@release_version} - 
RC0
 Hi,
 
 I would like to propose the following release candidate (RC0) of Apache
-Arrow version #{@release_version}. This is a release consiting of 
#{n_resolved_issues}
+Arrow version #{@release_version}. This is a release consisting of 
#{n_resolved_issues}
 resolved JIRA issues[1].
 
 This release candidate is based on commit:
diff --git a/dev/release/02-source.sh b/dev/release/02-source.sh
index dee1d75..0eca86d 100755
--- a/dev/release/02-source.sh
+++ b/dev/release/02-source.sh
@@ -148,7 +148,7 @@ Subject: [VOTE] Release Apache Arrow ${version} - RC${rc}
 Hi,
 
 I would like to propose the following release candidate (RC${rc}) of Apache
-Arrow version ${version}. This is a release consiting of ${n_resolved_issues}
+Arrow version ${version}. This is a release consisting of ${n_resolved_issues}
 resolved JIRA issues[1].
 
 This release candidate is based on commit:
diff --git a/dev/release/post-03-website.sh b/dev/release/post-03-website.sh
index b385866..1c7e3f7 100755
--- a/dev/release/post-03-website.sh
+++ b/dev/release/post-03-website.sh
@@ -230,7 +230,7 @@ cat <<YAML > "${versions_yml}"
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# Database of the current verion
+# Database of the current version
 #
 current:
   number: '${version}'
diff --git a/dev/tasks/conda-recipes/README.md 
b/dev/tasks/conda-recipes/README.md
index d5cfe3e..a31dbc2 100644
--- a/dev/tasks/conda-recipes/README.md
+++ b/dev/tasks/conda-recipes/README.md
@@ -20,7 +20,7 @@
 # Conda Forge recipes
 
 This directory must be migrated periodically with the upstrem updates of
-[arrow-cpp-feedstock][arrow-cpp-feedsotkc],
+[arrow-cpp-feedstock][arrow-cpp-feedstock],
 [parquet-cpp-feedstock][parquet-cpp-feedstock] and
 [pyarrow-feedstock][pyarrow-feedstock]
 conda-forge repositories because of multiple vendored files.
@@ -34,7 +34,7 @@ latest releases.
 ### Backporting from the upstream feedstocks
 
 In most of the cases these recipes are more accurate, then the upstream
-feedstocks. Altough the upstream feedstocks regurarly receive automatic updates
+feedstocks. Although the upstream feedstocks regularly receive automatic 
updates
 by the conda-forge team so we need to backport those changes to the crossbow
 recipes. Most of these updates are touching the version pinning files
 (under `.ci_support`) and other CI related configuration files.
diff --git a/dev/tasks/linux-packages/apache-arrow/yum/arrow.spec.in 
b/dev/tasks/linux-packages/apache-arrow/yum/arrow.spec.in
index fd6ba2a..f14539e 100644
--- a/dev/tasks/linux-packages/apache-arrow/yum/arrow.spec.in
+++ b/dev/tasks/linux-packages/apache-arrow/yum/arrow.spec.in
@@ -310,7 +310,7 @@ Libraries and header files for Apache Arrow Flight.
 
 %if %{use_gandiva}
 %package -n gandiva-libs
-Summary:       C++ library for compiling and evaluating exressions on Apache 
Arrow data.
+Summary:       C++ library for compiling and evaluating expressions on Apache 
Arrow data.
 License:       Apache-2.0
 Requires:      %{name}-libs = %{version}-%{release}
 Requires:      ncurses-libs

Reply via email to
diff --git a/dev/tasks/crossbow.py b/dev/tasks/crossbow.py
index d73fa20..820da70 100755
--- a/dev/tasks/crossbow.py
+++ b/dev/tasks/crossbow.py
@@ -224,7 +224,7 @@ class GitRemoteCallbacks(PygitRemoteCallbacks):
         pass
 
     def credentials(self, url, username_from_url, allowed_types):
-        # its a libgit2 bug, that it infinitly retries the authentication
+        # its a libgit2 bug, that it infinitely retries the authentication
         self.attempts += 1
 
         if self.attempts >= 5:
@@ -331,7 +331,7 @@ class Repo:
         """Currently checked out branch's remote counterpart URL
 
         If an SSH github url is set, it will be replaced by the https
         equivalent usable with Github OAuth token.
         """
         try:
             return self._remote_url or _git_ssh_to_https(self.remote.url)
@@ -343,14 +343,14 @@ class Repo:
         try:
             return next(self.repo.config.get_multivar('user.name'))
         except StopIteration:
-            return os.environ.get('GIT_COMMITTER_NAME', 'unkown')
+            return os.environ.get('GIT_COMMITTER_NAME', 'unknown')
 
     @property
     def user_email(self):
         try:
             return next(self.repo.config.get_multivar('user.email'))
         except StopIteration:
-            return os.environ.get('GIT_COMMITTER_EMAIL', 'unkown')
+            return os.environ.get('GIT_COMMITTER_EMAIL', 'unknown')
 
     @property
     def signature(self):
@@ -442,7 +442,7 @@ class Repo:
                              or action_required, only set if
                              CheckRun.status == 'completed'
 
-        1. Convert CheckRun's status and conslusion to one of Status.state
+        1. Convert CheckRun's status and conclusion to one of Status.state
         2. Merge the states based on the following rules:
            - failure if any of the contexts report as error or failure
            - pending if there are no statuses or a context is pending
@@ -475,7 +475,7 @@ class Repo:
                 elif check.conclusion in {'cancelled', 'timed_out',
                                           'action_required'}:
                     states.append('error')
-                # omit `neutral` conslusion
+                # omit `neutral` conclusion
             else:
                 states.append('pending')
 
@@ -1122,7 +1122,7 @@ def changelog(obj, changelog_path, arrow_version, 
is_website, jira_username,
 @click.option('--arrow-version', '-v', default=None,
               help='Set target version explicitly.')
 @click.option('--arrow-remote', '-r', default=None,
-              help='Set Github remote explicitly, which is going to be cloned '
+              help='Set GitHub remote explicitly, which is going to be cloned '
                    'on the CI services. Note, that no validation happens '
                    'locally. Examples: https://github.com/apache/arrow or '
                    'https://github.com/kszucs/arrow.')
@@ -331,7 +331,7 @@ class Repo:
 
         If an SSH github url is set, it will be replaced by the https
-        equivalent usable with Github OAuth token.
+        equivalent usable with GitHub OAuth token.
         """
         try: